@@ -6,10 +6,10 @@ import json
 
 import click
 
-from ... import Settings
+from ... import Fastberry
 from .shell import shell_commands, shell_print
 
-settings = Settings()
+settings = Fastberry()
 
 
 @click.command()
@@ -21,15 +21,15 @@ settings = Settings()
     help="Server Mode.",
 )
 @click.option("-p", "--port", default=8000, help="Port Number.")
-@click.option("-w", "--workers", default=1, help="Workers Number.")
+@click.option("-w", "--workers", default=1, help="Number of Workers.")
 def run(mode, port, workers):
     """Start FastApi Server
 
     \b
     # Examples
-        - development : ./manage.py run --port 8001 --mode development
-        - staging     : ./manage.py run --port 8001 --mode staging
-        - production  : ./manage.py run --mode production
+        - development : ./manage.py run --port 8000 --mode development
+        - staging     : ./manage.py run --port 8000 --mode staging
+        - production  : ./manage.py run --port 8000 --mode production --workers 4
     """
 
     # SETUP
@@ -53,6 +53,8 @@ def run(mode, port, workers):
 
     # PY-Lint
     if mode == "development":
+        logs_dir = base_dir / "logs"
+        logs_dir.mkdir(parents=True, exist_ok=True)
         return_value.append("""python scripts/pylint.py > logs/pylint.log 2>&1 &""")
 
     # FastAPI-Server
@@ -60,10 +62,10 @@ def run(mode, port, workers):
         case "development":
             run_server = f"python -m uvicorn main:app --reload --port { port }"
         case "staging":
-            run_server = f"python -m uvicorn main:app --reload --port { port }"
+            run_server = f"python -m gunicorn main:app --workers { workers } --worker-class uvicorn.workers.UvicornWorker --bind 0.0.0.0:{ port }"
         case "production":
             run_server = f"python -m gunicorn main:app --workers { workers } --worker-class uvicorn.workers.UvicornWorker --bind 0.0.0.0:{ port }"
-                    
+
     return_value.append(run_server)
 
     # Message
